## Project Title

```aphorism```

## Installing / Upgrading / Uninstalling ```aphorism```

Installing ```aphorism``` is as easy as opening a command line/terminal and calling: 

```
pip install aphorism
```

Optionally, you can install specific versions or upgrade in the standard ways, respectively:

```
pip install aphorism==versionnumber
pip install --upgrade aphorism
```

Uninstalling also works as you expect:

```
pip uninstall aphorism
```

## Importing ```aphorism```

Importing aphorism is as easy as: 

```
import aphorism
```

All standard Python syntaxes apply once imported, and subsets or subpackages of ```aphorism``` can be imported in the standard way: 

```
from aphorism import ... (as ...)
```

## Project Motivation

To provide a structured, clean environment for my python code, examples, and historical work products.


## Current To-Do and Feature Enhancement List

- Need to figure out how to add/access data in the folder. I can see it, but I can't access it. 
- Need to figure out why the package won't let me install required packages even when they are listed under install_requires.
- Build the COVID reporting functions into a module.
- Build the COVID reporting data structures/examples into the module.
- Build out the general function file with all of the various functions. 
- Need to finish merging in the OPPE code for locations, volumes, readmissions, ...
- Need to finish adding all of the LaTeX and SQL files to this after patient info is cleaned.
- Need to complete the markdown file with all appropriate notations and sections.
- Need to finish the GUI that directly interacts with the data files/folders.
- Set up a repository for the *.shp files with a link to the US Census Bureau.
- Create a complete resource/reference section. Make sure to include a link to GitHub with the info on generating __init__.py, setup.py, and setup.cfg.

